from setuptools import setup

setup(name='ftThanos',
version="0.0.47",
description="A client for 47 API",
author="Thanos 47",
author_email="thanos@47paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
